@@ -1,4 +1,4 @@
-from url_cleaner import UrlCleaner,MODULE_DIR
+from url_cleaner import UrlCleaner
 
 if __name__ == '__main__':
     c = UrlCleaner()
